RenderConfigMessage class

Configuration message sent to native for rendering

Constructors

RenderConfigMessage({double? width, double? height, required double marginLeft, required double marginTop, required double marginRight, required double marginBottom, required double devicePixelRatio, required int assetLoadTimeoutMs, required bool continuousMode, String? baseUrl, String? postLoadScript})

Properties

assetLoadTimeoutMs int
Maximum time (ms) to wait for assets to load
getter/setter pair
baseUrl String?
Base URL for resolving relative asset paths
getter/setter pair
continuousMode bool
Generate single continuous page without page breaks
getter/setter pair
devicePixelRatio double
Device pixel ratio for rendering (default: 2.0)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
Output height in points (1/72 inch). Null = auto-detect from content.
getter/setter pair
marginBottom double
Bottom margin in points
getter/setter pair
marginLeft double
Left margin in points
getter/setter pair
marginRight double
Right margin in points
getter/setter pair
marginTop double
Top margin in points
getter/setter pair
postLoadScript String?
Optional JavaScript to execute after content loads
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
Output width in points (1/72 inch). Null = auto-detect from content.
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) RenderConfigMessage