RenderRequest class
Request to render HTML to PDF
Constructors
- RenderRequest({required String html, required RenderConfigMessage config})
Properties
- config ↔ RenderConfigMessage
-
Rendering configuration
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- html ↔ String
-
The HTML string to render
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → RenderRequest