RenderResponse class

Response containing rendered PDF bytes

Constructors

RenderResponse({required Uint8List bytes, required int durationMs})

Properties

bytes Uint8List
The PDF file bytes
getter/setter pair
durationMs int
Rendering duration in milliseconds
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) RenderResponse